@@ -300,7 +300,14 @@ class EngagementRateFB:
         df_posts_full = self.df_posts_full
         try:
             df_eng_by_day = deepcopy(df_posts_full)
-
+            df_post_by_date = df_eng_by_day
+            df_post_by_date = df_post_by_date[["date", "post_id"]]
+            df_post_by_date = (
+                df_post_by_date.groupby("date")["post_id"]
+                .apply(list)
+                .reset_index(name="list_id_post")
+            )
+            df_post_by_date = df_post_by_date.list_id_post
             df_eng_by_day = (
                 df_eng_by_day[
                     [
@@ -377,14 +384,16 @@ class EngagementRateFB:
                 df_eng_by_day, METRIC, ITEM_COLUMN
             ).categorize()
 
+            df_eng_by_day["list_post_id"] = df_post_by_date
             return df_eng_by_day[
                 PAGE_COLUMNS
                 + [
                     "group",
                     "date",
-                    "engagement_rate_by_day",
                     "boundary",
                     "rel_engagement_rate_by_day",
+                    "engagement_rate_by_day",
+                    "list_post_id",
                 ]
             ].dropna(subset=["engagement_rate_by_day"])
 
