@@ -181,7 +181,25 @@ class PolarityDistributionFB:
 
         # groups texts and returns data frame
         try:
-            if group_by == "account":
+            if group_by == "post":
+                df_groupedpolarity = (
+                    self.df_comments_full.groupby(
+                        ["post_id", "page_id", "page_name", "group"]
+                    )["polarity"]
+                    .value_counts()
+                    .unstack()
+                    .fillna(0)
+                )
+                df_groupedpolarity["sentiment"] = df_groupedpolarity.to_dict(
+                    orient="records"
+                )
+                df_groupedpolarity = df_groupedpolarity.reset_index().rename(
+                    columns={"page_id": "_object_id", "page_name": "_object_name"}
+                )
+                return df_groupedpolarity[
+                    ["post_id", "_object_id", "_object_name", "group", "sentiment"]
+                ]
+            elif group_by == "account":
                 df_groupedpolarity = (
                     self.df_comments_full.groupby(["page_id", "page_name", "group"])[
                         "polarity"
@@ -221,6 +239,24 @@ class PolarityDistributionFB:
                     orient="records"
                 )
                 return df_groupedpolarity.reset_index()[["all", "sentiment"]]
+            elif group_by == "time-account":
+                df_groupedpolarity = (
+                    self.df_comments_full.groupby(
+                        ["created_time", "page_id", "page_name"]
+                    )["polarity"]
+                    .value_counts()
+                    .unstack()
+                    .fillna(0)
+                )
+                df_groupedpolarity["sentiment"] = df_groupedpolarity.to_dict(
+                    orient="records"
+                )
+                df_groupedpolarity = df_groupedpolarity.reset_index().rename(
+                    columns={"page_id": "_object_id", "page_name": "_object_name"}
+                )
+                return df_groupedpolarity.reset_index()[
+                    ["created_time", "_object_id", "_object_name", "sentiment"]
+                ]
             else:
                 print(
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
@@ -255,4 +291,4 @@ class PolarityDistributionFB:
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
                 )
                 df_groupedpolarity = pd.DataFrame(columns=["all", "sentiment"])
-            return self.df_groupedpolarity
+            return df_groupedpolarity
