@@ -10,7 +10,7 @@ ERR_SYS = "\nSystem error: "
 
 
 class EngagementRateIG:
-    def __init__(self, df_posts, df_pages, groups):
+    def __init__(self, df_posts, df_pages, groups, mode="status"):
         """
         This method computes the DataFrame 'df_posts_full' with the columns
         'group' and 'followers' which is a count of the fans in the day the post was made.
@@ -33,96 +33,149 @@ class EngagementRateIG:
 
         METHOD_NAME = "__init__"
 
-        PAGES_COLUMNS = ["followers", "userid", "date"]
-        POSTS_COLUMNS = [
-            "owner_id",
-            "owner_username",
-            "date_utc",
-            "shortcode",
-            "likes_count",
-            "comment_count",
-            "caption_hashtags",
-            "typename",
-            "caption_mentions",
-            "caption",
-        ]
-        OUTPUT_COLUMNS = [
-            "followers",
-            "owner_id",
-            "owner_username",
-            "group",
-            "created_at",
-            "shortcode",
-            "likes_count",
-            "comment_count",
-            "caption_hashtags",
-            "typename",
-            "caption_mentions",
-            "caption",
-        ]
+        self.mode = mode
 
-        if len(df_posts) > 0 and len(df_pages) > 0:
+        if self.mode == "status":
+            PAGES_COLUMNS = ["followers", "userid", "date"]
+
+            POSTS_COLUMNS = [
+                "owner_id",
+                "owner_username",
+                "date_utc",
+                "shortcode",
+                "likes_count",
+                "comment_count",
+                "caption_hashtags",
+                "typename",
+                "caption_mentions",
+                "caption",
+            ]
+            OUTPUT_COLUMNS = [
+                "followers",
+                "owner_id",
+                "owner_username",
+                "group",
+                "created_at",
+                "shortcode",
+                "likes_count",
+                "comment_count",
+                "caption_hashtags",
+                "typename",
+                "caption_mentions",
+                "caption",
+            ]
+
+            if len(df_posts) > 0 and len(df_pages) > 0:
+                try:
+                    df_fan_count = deepcopy(df_pages[PAGES_COLUMNS])
+                    df_fan_count["userid"] = df_fan_count["userid"].apply(
+                        lambda uid: str(uid)
+                    )
+
+                    df_fan_count["date"] = pd.to_datetime(
+                        df_fan_count["date"], format="%Y-%m-%dT%H:%M:%S"
+                    )
+                    df_fan_count["date"] = pd.to_datetime(
+                        df_fan_count["date"]
+                    ) - timedelta(hours=5)
+                    df_fan_count["date"] = df_fan_count["date"].apply(lambda d: d.date)
+                    df_fan_count = (
+                        df_fan_count.groupby(["userid", "date"]).last().reset_index()
+                    )
+
+                    df_fan_count = df_fan_count.rename(columns={"userid": "owner_id"})
+
+                    df_posts_full = deepcopy(df_posts[POSTS_COLUMNS])
+                    df_posts_full["owner_id"] = df_posts_full["owner_id"].apply(
+                        lambda uid: str(uid)
+                    )
+
+                    df_posts_full["date"] = pd.to_datetime(
+                        df_posts_full["date_utc"], format="%Y-%m-%dT%H:%M:%S"
+                    )
+                    df_posts_full["created_at"] = pd.to_datetime(
+                        df_posts_full["date"]
+                    ) - timedelta(hours=5)
+                    df_posts_full["date"] = pd.to_datetime(
+                        df_posts_full["date"]
+                    ) - timedelta(hours=5)
+                    df_posts_full["date"] = df_posts_full["date"].apply(
+                        lambda d: d.date
+                    )
+                    df_posts_full = pd.merge(
+                        df_posts_full, df_fan_count, on=["owner_id", "date"], how="left"
+                    )
+                    df_posts_full["followers"] = df_posts_full.sort_values(
+                        ["owner_id", "date"]
+                    )["followers"].fillna(method="bfill")
+
+                    df_posts_full = df_posts_full.sort_values("date").drop_duplicates(
+                        subset=["shortcode"], keep="last"
+                    )
+
+                    df_posts_full["group"] = df_posts_full["owner_id"].apply(
+                        lambda pid: general_utils.get_group(pid, groups)
+                    )
+
+                    self.df_posts_full = df_posts_full
+
+                except Exception as e:
+                    exception_type = sys.exc_info()[0]
+                    print(ERR_SYS + str(exception_type))
+                    print(e)
+                    print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
+                    self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
+
+            else:
+                print("Warning: One of the DataFrames is empty. It cannot be computed.")
+                self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
+        elif self.mode == "hashtags":
+            HASHTAG_COLUMNS = [
+                "caption",
+                "comments_count",
+                "like_count",
+                "media_type",
+                "timestamp",
+            ]
+            OUTPUT_COLUMNS = [
+                "followers",
+                "group",
+                "created_at",
+                "likes_count",
+                "comment_count",
+                "typename",
+                "caption",
+            ]
             try:
-                df_fan_count = deepcopy(df_pages[PAGES_COLUMNS])
-                df_fan_count["userid"] = df_fan_count["userid"].apply(
-                    lambda uid: str(uid)
+                df_hashtag_full = deepcopy(
+                    df_posts[HASHTAG_COLUMNS]
+                )  # df_hashtag camuflado
+                df_hashtag_full = df_hashtag_full.rename(
+                    columns={
+                        "comments_count": "comment_count",
+                        "like_count": "likes_count",
+                        "media_type": "typename",
+                        "timestamp": "date_utc",
+                    }
                 )
 
-                df_fan_count["date"] = pd.to_datetime(
-                    df_fan_count["date"], format="%Y-%m-%dT%H:%M:%S"
+                df_hashtag_full = df_hashtag_full.drop_duplicates()
+                df_hashtag_full["followers"] = 1
+                df_hashtag_full["group"] = "hashtags"
+                df_hashtag_full["date"] = pd.to_datetime(
+                    df_hashtag_full["date_utc"], format="%Y-%m-%dT%H:%M:%S"
                 )
-                df_fan_count["date"] = pd.to_datetime(df_fan_count["date"]) - timedelta(
-                    hours=5
-                )
-                df_fan_count["date"] = df_fan_count["date"].apply(lambda d: d.date)
-                df_fan_count = (
-                    df_fan_count.groupby(["userid", "date"]).last().reset_index()
-                )
-
-                df_fan_count = df_fan_count.rename(columns={"userid": "owner_id"})
-
-                df_posts_full = deepcopy(df_posts[POSTS_COLUMNS])
-                df_posts_full["owner_id"] = df_posts_full["owner_id"].apply(
-                    lambda uid: str(uid)
-                )
-
-                df_posts_full["date"] = pd.to_datetime(
-                    df_posts_full["date_utc"], format="%Y-%m-%dT%H:%M:%S"
-                )
-                df_posts_full["created_at"] = pd.to_datetime(
-                    df_posts_full["date"]
+                df_hashtag_full["created_at"] = pd.to_datetime(
+                    df_hashtag_full["date"]
                 ) - timedelta(hours=5)
-                df_posts_full["date"] = pd.to_datetime(
-                    df_posts_full["date"]
-                ) - timedelta(hours=5)
-                df_posts_full["date"] = df_posts_full["date"].apply(lambda d: d.date)
-                df_posts_full = pd.merge(
-                    df_posts_full, df_fan_count, on=["owner_id", "date"], how="left"
-                )
-                df_posts_full["followers"] = df_posts_full.sort_values(
-                    ["owner_id", "date"]
-                )["followers"].fillna(method="bfill")
-
-                df_posts_full = df_posts_full.sort_values("date").drop_duplicates(
-                    subset=["shortcode"], keep="last"
-                )
-
-                df_posts_full["group"] = df_posts_full["owner_id"].apply(
-                    lambda pid: general_utils.get_group(pid, groups)
-                )
-
-                self.df_posts_full = df_posts_full
-
+                self.df_posts_full = df_hashtag_full[OUTPUT_COLUMNS]
             except Exception as e:
                 exception_type = sys.exc_info()[0]
                 print(ERR_SYS + str(exception_type))
                 print(e)
                 print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
-                self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS, dtype=object)
-
         else:
-            print("Warning: One of the DataFrames is empty. It cannot be computed.")
-            self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS, dtype=object)
+            self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
 
     def by_reach(self):
         """
@@ -139,13 +192,27 @@ class EngagementRateIG:
 
         df_posts_full = self.df_posts_full
         try:
-            df_posts_full["engagement_rate_by_reach"] = df_posts_full.apply(
-                lambda row: 100
-                * (row.likes_count + row.comment_count)
-                / row.reach_count,
-                axis=1,
-            )
-            return df_posts_full.dropna(subset=["engagement_rate_by_reach"])
+            if self.mode == "hashtags":
+                df_posts_full["engagement_rate_by_post"] = df_posts_full.apply(
+                    lambda row: (row.likes_count + row.comment_count) / row.followers,
+                    axis=1,
+                )
+
+            else:
+                df_posts_full["engagement_rate_by_post"] = df_posts_full.apply(
+                    lambda row: 100
+                    * (row.likes_count + row.comment_count)
+                    / row.followers,
+                    axis=1,
+                )
+                METRIC = "engagement_rate_by_post"
+                ITEM_COLUMN = "owner_id"
+                df_posts_full = df_posts_full.sort_values(by=["created_at"])
+                df_posts_full = metric_transformation.MetricCategorization(
+                    df_posts_full, METRIC, ITEM_COLUMN
+                ).categorize()
+
+            return df_posts_full.dropna(subset=["engagement_rate_by_post"])
 
         except Exception as e:
             exception_type = sys.exc_info()[0]
@@ -153,7 +220,8 @@ class EngagementRateIG:
             print(e)
             print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
             return pd.DataFrame(
-                columns=list(df_posts_full.columns) + ["engagement_rate_by_reach"]
+                columns=list(df_posts_full.columns)
+                + ["engagement_rate_by_post", "boundary", "rel_engagement_rate_by_post"]
             )
 
     def by_post(self):
@@ -255,6 +323,15 @@ class EngagementRateIG:
         try:
             df_eng_by_day = deepcopy(df_posts_full)
 
+            df_post_by_date = df_eng_by_day
+            df_post_by_date = df_post_by_date[["date", "mediaid"]]
+            df_post_by_date = (
+                df_post_by_date.groupby("date")["mediaid"]
+                .apply(list)
+                .reset_index(name="list_id_post")
+            )
+            df_post_by_date = df_post_by_date.list_id_post
+
             df_eng_by_day = (
                 df_eng_by_day[
                     [
@@ -304,6 +381,7 @@ class EngagementRateIG:
             df_eng_by_day = metric_transformation.MetricCategorization(
                 df_eng_by_day, METRIC, ITEM_COLUMN
             ).categorize()
+            df_eng_by_day["list_post_id"] = df_post_by_date
 
             return df_eng_by_day[
                 PAGE_COLUMNS
@@ -313,6 +391,7 @@ class EngagementRateIG:
                     "engagement_rate_by_day",
                     "boundary",
                     "rel_engagement_rate_by_day",
+                    "list_post_id",
                 ]
             ].dropna(subset=["engagement_rate_by_day"])
 
