@@ -147,7 +147,21 @@ class PolarityDistributionIG:
             self.df_comments_full = self.df_comments_full.dropna(subset=["polarity"])
 
         try:
-            if group_by == "account":
+            if group_by == "post":
+                df_groupedpolarity = (
+                    self.df_comments_full.groupby("_post_id")["polarity"]
+                    .value_counts()
+                    .unstack()
+                    .fillna(0)
+                )
+                df_groupedpolarity["sentiment"] = df_groupedpolarity.to_dict(
+                    orient="records"
+                )
+                df_groupedpolarity = df_groupedpolarity.reset_index().rename(
+                    columns={"_postr_id": "post_id"}
+                )
+                return df_groupedpolarity.reset_index()[["post_id", "sentiment"]]
+            elif group_by == "account":
                 df_groupedpolarity = (
                     self.df_comments_full.groupby(
                         ["post_owner_id", "post_owner_username", "group"]
@@ -190,6 +204,24 @@ class PolarityDistributionIG:
                     orient="records"
                 )
                 return df_groupedpolarity.reset_index()[["all", "sentiment"]]
+            elif group_by == "time-account":
+                df_groupedpolarity = (
+                    self.df_comments_full.groupby(
+                        ["_created_at", "_post_id", "_object_name"]
+                    )["polarity"]
+                    .value_counts()
+                    .unstack()
+                    .fillna(0)
+                )
+                df_groupedpolarity["sentiment"] = df_groupedpolarity.to_dict(
+                    orient="records"
+                )
+                df_groupedpolarity = df_groupedpolarity.reset_index().rename(
+                    columns={"_created_at": "created_time", "_post_id": "_object_id"}
+                )
+                return df_groupedpolarity.reset_index()[
+                    ["created_time", "_object_id", "_object_name", "sentiment"]
+                ]
             else:
                 print(
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
