@@ -366,6 +366,15 @@ class EngagementRateTW:
 
             df_eng_by_day["date"] = df_eng_by_day.created_at.apply(lambda d: d.date)
 
+            df_post_by_date = df_eng_by_day
+            df_post_by_date = df_post_by_date[["date", "tweet_id"]]
+            df_post_by_date = (
+                df_post_by_date.groupby("date")["tweet_id"]
+                .apply(list)
+                .reset_index(name="list_id_post")
+            )
+            df_post_by_date = df_post_by_date.list_id_post
+
             df_eng_by_day = (
                 df_eng_by_day[
                     [
@@ -419,7 +428,7 @@ class EngagementRateTW:
             df_eng_by_day = metric_transformation.MetricCategorization(
                 df_eng_by_day, METRIC, ITEM_COLUMN
             ).categorize()
-
+            df_eng_by_day["list_post_id"] = df_post_by_date
             return df_eng_by_day[
                 PAGE_COLUMNS
                 + [
@@ -428,6 +437,7 @@ class EngagementRateTW:
                     "engagement_rate_by_day",
                     "boundary",
                     "rel_engagement_rate_by_day",
+                    "list_post_id",
                 ]
             ].dropna(subset=["engagement_rate_by_day"])
 
