@@ -149,7 +149,29 @@ class PolarityDistributionTW:
             self.df_replies_full = self.df_replies_full.dropna(subset=["polarity"])
 
         try:
-            if group_by == "account":
+            if group_by == "post":
+                df_groupedpolarity = (
+                    self.df_replies_full.groupby(
+                        ["in_reply_to_status_id", "page_id", "page_name", "group"]
+                    )["polarity"]
+                    .value_counts()
+                    .unstack()
+                    .fillna(0)
+                )
+                df_groupedpolarity["sentiment"] = df_groupedpolarity.to_dict(
+                    orient="records"
+                )
+                df_groupedpolarity = df_groupedpolarity.reset_index().rename(
+                    columns={
+                        "in_reply_to_status_id": "post_id",
+                        "page_id": "_object_id",
+                        "page_name": "_object_name",
+                    }
+                )
+                return df_groupedpolarity[
+                    ["post_id", "_object_id", "_object_name", "group", "sentiment"]
+                ]
+            elif group_by == "account":
                 df_groupedpolarity = (
                     self.df_replies_full.groupby(["page_id", "page_name", "group"])[
                         "polarity"
@@ -189,6 +211,28 @@ class PolarityDistributionTW:
                     orient="records"
                 )
                 return df_groupedpolarity.reset_index()[["all", "sentiment"]]
+            elif group_by == "time-account":
+                df_groupedpolarity = (
+                    self.df_replies_full.groupby(
+                        ["created_at", "page_id", "page_name"]
+                    )["polarity"]
+                    .value_counts()
+                    .unstack()
+                    .fillna(0)
+                )
+                df_groupedpolarity["sentiment"] = df_groupedpolarity.to_dict(
+                    orient="records"
+                )
+                df_groupedpolarity = df_groupedpolarity.reset_index().rename(
+                    columns={
+                        "created_at": "created_time",
+                        "page_id": "_object_id",
+                        "page_name": "_object_name",
+                    }
+                )
+                return df_groupedpolarity.reset_index()[
+                    ["created_time", "_object_id", "_object_name", "sentiment"]
+                ]
             else:
                 print(
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
@@ -222,4 +266,4 @@ class PolarityDistributionTW:
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
                 )
                 df_groupedpolarity = pd.DataFrame(columns=["all", "sentiment"])
-            return self.df_groupedpolarity
+            return df_groupedpolarity
