@@ -55,6 +55,7 @@ class TermTrend:
             "user_mentions",
             "profile_image",
             "engagement_rate_by_post",
+            "tweet_id",
         ]
 
         try:
@@ -98,6 +99,7 @@ class TermTrend:
         METHOD_NAME = "time_series"
 
         df_tweets_out = deepcopy(self.df_tweets_in[["created_at"]])
+        df_tweets_id = deepcopy(self.df_tweets_in[["created_at", "tweet_id"]])
 
         try:
             df_tweets_out["mention_counts"] = 1
@@ -106,6 +108,16 @@ class TermTrend:
                     year=dt.year, month=dt.month, day=dt.day, hour=dt.hour
                 )
             )
+            df_tweets_id["created_at"] = df_tweets_out["created_at"].apply(
+                lambda dt: datetime(
+                    year=dt.year, month=dt.month, day=dt.day, hour=dt.hour
+                )
+            )
+            df_tweets_id = (
+                df_tweets_id.groupby("created_at")["tweet_id"]
+                .apply(list)
+                .reset_index(name="list_id_post")
+            )
             df_tweets_out = (
                 df_tweets_out.groupby("created_at")
                 .count()
@@ -113,6 +125,7 @@ class TermTrend:
                 .sort_values("created_at")
             )
             df_tweets_out["level"] = level
+            df_tweets_out["list_post_id"] = df_tweets_id["list_id_post"]
 
             return df_tweets_out
 
